#ifndef FN603_H
#define FN603_H

#ifdef FN603_Exports
#define FN603_API __declspec(dllexport)
#else
#define FN603_API __declspec(dllimport)
#endif

extern "C"
 {
//Open device named as "FN-603":
//returns true if device opens correctly.
  FN603_API bool WINAPI FN603_OpenDevice(void);

//Close device:
//returns true if device closes correctly.
  FN603_API bool WINAPI FN603_CloseDevice(void);

//Get last error name:
//returns pointer to last error name string
//(empty string if error not occured).
  FN603_API void WINAPI FN603_GetLastError(LPCSTR &lpcStr);

//Get device info:
//returns pointer to device name string.
//Device name string is "FN-603 V1.0", where
//"FN-603" is device name, "V1.0" is firmware version
//(may be different).
//Returns true if device responds correctly.
  FN603_API bool WINAPI FN603_GetInfo(LPCSTR &lpcStr);

//Get temperature:
//t1..t6 - temperature for channels 1..6, range -400..+1250  0.1C
//Returns true if device responds correctly.
  FN603_API bool WINAPI FN603_GetT(int &t1, int &t2, int &t3,
                                   int &t4, int &t5, int &t6);
//Get fan RPM:
//t1..t6 - fan speed for channels 1..6, range 0..9999 rpm
//Returns true if device responds correctly.
  FN603_API bool WINAPI FN603_GetV(int &v1, int &v2, int &v3,
                                   int &v4, int &v5, int &v6);
//Set mode:
//chan - channel number 1..6
//mode.0 - boost enable
//mode.1 - auto enable
//mode.2 - alarm temperature enable
//mode.3 - alarm speed enable
//Tmin - minimum slope temperature, range -400..+1250  0.1C
//Pmin - minimum slope PWM, range 0..255
//Tmax - maximum slope temperature, range -400..+1250  0.1C
//Pmax - maximum slope PWM, range 0..255
//At - alarm (maximum) temperature, range -400..+1250  0.1C
//Av - alarm (minimum) sped, range 0..9999 rpm
//Returns true if device responds correctly.
  FN603_API bool WINAPI FN603_SetM(int chan, int mode, int Tmin, int Pmin,
                             int Tmax, int Pmax, int At, int Av, int Pman);
//Get mode:
//chan - channel number 1..6
//mode.0 - boost enable
//mode.1 - auto enable
//mode.2 - alarm temperature enable
//mode.3 - alarm speed enable
//Tmin - minimum slope temperature, range -400..+1250  0.1C
//Pmin - minimum slope PWM, range 0..255
//Tmax - maximum slope temperature, range -400..+1250  0.1C
//Pmax - maximum slope PWM, range 0..255
//At - alarm (maximum) temperature, range -400..+1250  0.1C
//Av - alarm (minimum) sped, range 0..9999 rpm
//Returns true if device responds correctly.
  FN603_API bool WINAPI FN603_GetM(int chan, int &mode, int &Tmin, int &Pmin,
                           int &Tmax, int &Pmax, int &At, int &Av, int &Pman);
//Set PWM:
//p1..p6 - PWM for channels 1..6, range 0..255
//Returns true if device responds correctly.
  FN603_API bool WINAPI FN603_SetPWM(int p1, int p2, int p3,
                                     int p4, int p5, int p6);
//Get PWM:
//p1..p6 - PWM for channels 1..6, range 0..255
//Returns true if device responds correctly.
  FN603_API bool WINAPI FN603_GetPWM(int &p1, int &p2, int &p3,
                                     int &p4, int &p5, int &p6);
 }
#endif


